@@ -26,11 +26,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <string.h>
+#include <config.h>
+#include "gnome-vfs-mime-sniff-buffer.h"
 
+#include "gnome-vfs-handle.h"
 #include "gnome-vfs-mime-sniff-buffer-private.h"
 #include "gnome-vfs-ops.h"
-
+#include <string.h>
 
 static GnomeVFSResult
 handle_seek_glue (gpointer context, GnomeVFSSeekPosition whence, 
@@ -49,7 +51,7 @@ handle_read_glue (gpointer context, gpointer buffer,
 }
 
 GnomeVFSMimeSniffBuffer *
-gnome_vfs_mime_sniff_buffer_new_from_handle (GnomeVFSHandle *file)
+_gnome_vfs_mime_sniff_buffer_new_from_handle (GnomeVFSHandle *file)
 {
 	GnomeVFSMimeSniffBuffer *result;
 
@@ -63,7 +65,7 @@ gnome_vfs_mime_sniff_buffer_new_from_handle (GnomeVFSHandle *file)
 }
 
 GnomeVFSMimeSniffBuffer	*
-gnome_vfs_mime_sniff_buffer_new_generic (GnomeVFSSniffBufferSeekCall seek_callback, 
+_gnome_vfs_mime_sniff_buffer_new_generic (GnomeVFSSniffBufferSeekCall seek_callback, 
 					 GnomeVFSSniffBufferReadCall read_callback,
 					 gpointer context)
 {
@@ -80,8 +82,8 @@ gnome_vfs_mime_sniff_buffer_new_generic (GnomeVFSSniffBufferSeekCall seek_callba
 }
 
 GnomeVFSMimeSniffBuffer * 
-gnome_vfs_mime_sniff_buffer_new_from_memory (const guchar *buffer, 
-					     ssize_t buffer_length)
+_gnome_vfs_mime_sniff_buffer_new_from_memory (const guchar *buffer, 
+					     gssize buffer_length)
 {
 	GnomeVFSMimeSniffBuffer *result;
 
@@ -97,7 +99,7 @@ gnome_vfs_mime_sniff_buffer_new_from_memory (const guchar *buffer,
 
 GnomeVFSMimeSniffBuffer	*
 gnome_vfs_mime_sniff_buffer_new_from_existing_data (const guchar *buffer, 
-					 	    ssize_t buffer_length)
+					 	    gssize buffer_length)
 {
 	GnomeVFSMimeSniffBuffer *result;
 
@@ -124,8 +126,8 @@ enum {
 };
 
 GnomeVFSResult
-gnome_vfs_mime_sniff_buffer_get (GnomeVFSMimeSniffBuffer *buffer,
-				 ssize_t size)
+_gnome_vfs_mime_sniff_buffer_get (GnomeVFSMimeSniffBuffer *buffer,
+				 gssize size)
 {
 	GnomeVFSResult result;
 	GnomeVFSFileSize bytes_to_read, bytes_read;
@@ -177,3 +179,18 @@ gnome_vfs_mime_sniff_buffer_get (GnomeVFSMimeSniffBuffer *buffer,
 	/* not enough data */
 	return GNOME_VFS_ERROR_EOF;
 }
+
+/*
+ * gnome_vfs_get_mime_type_for_buffer:
+ * @buffer: a sniff buffer referencing either a file or data in memory
+ *
+ * This routine uses a magic database to guess the mime type of the
+ * data represented by @buffer.
+ *
+ * Returns a pointer to an internal copy of the mime-type for @buffer.
+ */
+const char *
+gnome_vfs_get_mime_type_for_buffer (GnomeVFSMimeSniffBuffer *buffer)
+{
+	return _gnome_vfs_get_mime_type_internal (buffer, NULL);
+}
